"""
SpeechBridge Components Module
================================

Main processing components:
- speech: Speech recognition (ASR)
- translation: Text translation
- tts: Text-to-speech synthesis
- video: Video processing
"""

__all__ = [
    'speech',
    'translation',
    'tts',
    'video',
]
