"""
SpeechBridge Framework Version Information
"""

__version__ = "1.0.0"
__author__ = "Kolpakov Andrey"
__license__ = "MIT"
__description__ = "Modular framework for automated video translation with GPU support"
